==> mochista-0.17.3.tgz: package/bin/index.js <==
#!/usr/bin/env node

const dotenv = require('dotenv');
dotenv.load();
let yargs = require('yargs');
const merge = require('merge-async-iterators');
const streamAsync = require('streams-to-async-iterator')
const options = require('./options');
const mochista = require('..');
const utils = require('../lib/utils');

yargs = yargs
  .scriptName(require('../package.json').name)
  .wrap(null)
  .options(options)
  .env('MOCHISTA')

let argv = yargs.argv;
dotenv.load({ path: argv.opts });
yargs = yargs.env();
argv = yargs.argv;

main(argv).catch(error => {
  process.exitCode = error.exitCode || 1;
  if (error instanceof utils.Error && !error.failures) {
    console.error(error.message);
  } else {
    if (!error.failures) {
      console.error(error);
    }
  }
});

async function main(argv = {}) {

  const { watcher, run } = await mochista(argv);
  const stdin = argv.watch && streamAsync(process.stdin.setEncoding('utf8'));
  const merged = merge([watcher, stdin].filter(Boolean), { yieldIterator: true });

  let firstRun = true;

  for await (const { iterator } of merged) {
    try {
      if (
        firstRun
        || iterator === stdin
        || !(typeof argv.watch === 'string' && argv.watch.startsWith('i'))
      ) {
        firstRun = false;
        await run();
      }
    } catch (error) {
      if (argv.watch) {
        if (!error.failures) {
          console.error(error);
        }
      } else {
        throw error;
      }
    }
    if (argv.watch) {
      process.stdout.write('Press Enter to re-run');
      process.stdout.cursorTo(0);
    } else {
      break;
    }
  }
}

==> mochista-0.18.0.tgz: package/bin/index.js <==
#!/usr/bin/env node

const dotenv = require('dotenv');
dotenv.load();
const Path = require('path');
let yargs = require('yargs');
const merge = require('merge-async-iterators');
const streamAsync = require('streams-to-async-iterator')
const options = require('./options');
const mochista = require('..');
const utils = require('lib/utils');

yargs = yargs
  .scriptName(require('../package.json').name)
  .wrap(null)
  .options(options)
  .env('MOCHISTA');

let argv = yargs.argv;
dotenv.load({ path: argv.opts });
yargs = yargs.env();
argv = yargs.argv;

process.env.NODE_V8_COVERAGE = argv.coverageDir = process.env.NODE_V8_COVERAGE || Path.join(argv.cwd || process.cwd(), argv.coverageDir || 'coverage', '.tmp');

main(argv).catch(error => {
  process.exitCode = error.exitCode || 1;
  if (error instanceof utils.Error && !error.failures) {
    console.error(error.message);
  } else {
    if (!error.failures) {
      console.error(error);
    }
  }
});

async function main(argv = {}) {

  const { watcher, run } = await mochista(argv);
  const stdin = argv.watch && streamAsync(process.stdin.setEncoding('utf8'));
  const merged = merge([watcher, stdin].filter(Boolean), { yieldIterator: true });

  let firstRun = true;

  for await (const { iterator } of merged) {
    try {
      if (
        firstRun
        || iterator === stdin
        || !(typeof argv.watch === 'string' && argv.watch.startsWith('i'))
      ) {
        firstRun = false;
        await run();
      }
    } catch (error) {
      if (argv.watch) {
        if (!error.failures) {
          console.error(error);
        }
      } else {
        throw error;
      }
    }
    if (argv.watch) {
      process.stdout.write('Press Enter to re-run');
      process.stdout.cursorTo(0);
    } else {
      break;
    }
  }
}
